<img align="right" width="96px" src="./assets/python3_logo.png">

# longbridge-utility

[![Test][test-ci-badge]][test-ci]
[![GitHub release][gh-release-badge]][gh-release]

## Sponsors

<p align="center">
  <a href="https://github.com/sponsors/Dup4">
    <img src='https://cdn.jsdelivr.net/gh/Dup4/static/sponsors-output/sponsors.svg' alt="Logos from Sponsors" />
  </a>
</p>

## License

[MIT](./LICENSE) License © 2023 [Dup4][dup4]

[dup4]: https://github.com/Dup4
[test-ci-badge]: https://github.com/Dup4/longbridge-utility/workflows/Test/badge.svg
[test-ci]: https://github.com/Dup4/longbridge-utility/actions/workflows/test.yml
[gh-release-badge]: https://img.shields.io/github/release/Dup4/longbridge-utility.svg
[gh-release]: https://GitHub.com/Dup4/longbridge-utility/releases/
